@@ -5,11 +5,9 @@ import fastapi
 import fastapi.responses
 
 from souswift_core import models
-from souswift_core.exc import exceptions, ext
+from souswift_core.exc import exceptions
 
-_Exception = Union[
-    exceptions.APIError, exceptions.DatabaseError, ext.ExtendedError
-]
+_Exception = Union[exceptions.APIError, exceptions.DatabaseError]
 
 
 def _api_error_handler(request: fastapi.Request, exc: exceptions.APIError):
@@ -40,20 +38,7 @@ def _database_error_handler(
     )
 
 
-def _extended_error_handler(request: fastapi.Request, exc: ext.ExtendedError):
-    exc_response = exc.response()
-    return fastapi.responses.ORJSONResponse(
-        models.ExtendedBaseError(
-            title=type(exc).__name__.lower(),
-            path=request.url.path,
-            status=exc_response.status_code,
-            detail=exc_response.message,
-            error_key=exc_response.error_key,
-        ).dict(by_alias=True)
-    )
-
-
-def _base_exception_handler(request: fastapi.Request, _: Exception):
+def _base_exception_handler(request: fastapi.Request, exc: Exception):
     status = http.HTTPStatus.INTERNAL_SERVER_ERROR
     return fastapi.responses.ORJSONResponse(
         models.BaseError(
@@ -74,7 +59,6 @@ def add_exception_handlers(
     for exception, handler in (
         (exceptions.APIError, _api_error_handler),
         (exceptions.DatabaseError, _database_error_handler),
-        (ext.ExtendedError, _extended_error_handler),
     ):
         if exception in exclude:
             continue
