@@ -1,7 +1,6 @@
-import abc
 import typing
 
-from sqlalchemy import Boolean, Column, Table
+from sqlalchemy import Boolean, Table
 from sqlalchemy.sql import ColumnElement
 from sqlalchemy.sql.elements import BooleanClauseList
 
@@ -24,9 +23,12 @@ class Filter:
         return self
 
 
-class Comparison(abc.ABC):
-    @abc.abstractmethod
-    def compare(
-        self, attr: Column | typing.Any, target: typing.Any
-    ) -> typing.Union[BooleanClauseList, 'ColumnElement[Boolean]']:
+ComparisonOutput = typing.Union[BooleanClauseList, 'ColumnElement[Boolean]']
+
+
+class Comparison(typing.Protocol):
+    def __call__(
+        self, attr: ColumnElement, expected: typing.Any
+    ) -> ComparisonOutput:
         """Receives column or function and returns a sqlalchemy comparison"""
+        ...
